% fig_02_17
% plot stereonet and projection of a linear element 
% Goodman and Shi (1985)
% equation (2.72)

%initialize and scale plot
clear all, clf reset, hold on % clear memory and figure, hold plot
axis equal, axis off, box off % equal scaling in x and y, no axes or box
axis ([-1 1 -1 1]) % sets scaling for x- and y-axes

% plot Cartesian coordinates and reference circle 
plot([-1 1],[0 0],'k:',[0 0],[-1 1],'k:') % plot x- and y-axes
r = 1; % radius of reference circle
TH = linspace(0,2*pi,3601); % polar angle, range 2 pi, 1/10 deg increment
[X,Y] = pol2cart(TH,r); % Cartesian coordinates of reference circle
plot(X,Y,'k') 

% loop to plot great circles at 10 degree increments
for j = 1:8
phid = j*(10*pi/180); % dip angle, phid
h = -r*tan(phid); rp = r/cos(phid); % x-coord of center, h, and radius, rp
X = -h + rp*cos(TH); Y = rp*sin(TH); % coordinates of pts on great circle
X(find(X.^2+Y.^2>r)) = nan; % eliminate points outside stereonet
plot(X,Y,'k:',-X,Y,'k:') % plot two sets of great circles
end

% loop to plot small circles at 10 degree increments
for j = 1:8 
gam = j*(10*pi/180); % cone angle, gam
k = r/cos(gam); rp = r*tan(gam); % y-coord of center, k, and radius, rp
X = rp*cos(TH); Y = k + rp*sin(TH); % coordinates of pts on small circle
Y(find(X.^2+Y.^2>r)) = nan; % eliminate points outside stereonet
plot(X,Y,'k:',X,-Y,'k:') % plot two sets of small circles
end

% enter plunge direction (azimuth angle) and plunge for planar element
alp = 223*pi/180; % plunge direction (azimuth) of linear element
phip = 33*pi/180; % plunge angle of linear element

% calculate Cartesian coordinates of projection and plot
x = r*tan(pi/4 - phip/2)*sin(alp); % x-coord of projection
y = r*tan(pi/4 - phip/2)*cos(alp); % y-coord of projection
plot(x,y,'ro')